##  Resources
For additional resources for further insights and support, see [SAP LeanIX Resources](https://help.sap.com/docs/leanix/ea/resources?locale=en-US&state=PRODUCTION&version=CLOUD "In addition to product documentation, there are several other resources to help you to get the most out of SAP LeanIX.").
